'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); /* eslint-disable filenames/match-exported */


require('isomorphic-fetch');

var _qs = require('qs');

var _qs2 = _interopRequireDefault(_qs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var mimeLib = {
  json: 'application/json',
  form: 'multipart/form-data',
  html: 'text/html',
  xml: 'application/xml',
  text: 'text/plain'
};

var Hifetch = function () {

  /* eslint-disable max-statements */
  function Hifetch(opt) {
    _classCallCheck(this, Hifetch);

    this._config = Object.assign({}, Hifetch.defaultConfig, opt);
    var _config = this._config,
        query = _config.query,
        method = _config.method,
        responseType = _config.responseType,
        data = _config.data,
        originDataType = _config.dataType,
        FormData = _config.FormData,
        headers = _config.headers,
        jwtToken = _config.jwtToken,
        enableCookies = _config.enableCookies,
        disableCORS = _config.disableCORS;

    this._queryString = query ? _qs2.default.stringify(query) : '';
    var fetchOpt = {};
    this._fetchOpt = fetchOpt;
    if (!disableCORS) {
      fetchOpt.mode = 'cors';
    }
    if (enableCookies) {
      fetchOpt.credentials = disableCORS ? 'same-origin' : 'include';
    }
    var moreHeaders = {
      Accept: /\//.test(responseType) ? responseType : mimeLib[responseType]
    };
    if (jwtToken) {
      moreHeaders.Authorization = 'Bearer ' + jwtToken;
    }
    var dataType = void 0;
    var dataForBody = data;
    var mergeToForm = function mergeToForm(dict) {
      Object.keys(dict).forEach(function (key) {
        dataForBody.append(key, dict[key]);
      });
    };
    if (data) {
      dataType = (/\//.test(originDataType) ? originDataType : mimeLib[originDataType]) || Hifetch.defaultConfig.dataType;
      if ((typeof data === 'undefined' ? 'undefined' : _typeof(data)) === 'object') {
        if (FormData && data instanceof FormData) {
          dataType = mimeLib.form;
        } else if (dataType === mimeLib.form) {
          dataForBody = new FormData();
          mergeToForm(data);
        } else if (dataType === Hifetch.defaultConfig.dataType) {
          dataForBody = _qs2.default.stringify(data);
        } else if (dataType.indexOf('json') !== -1) {
          dataForBody = JSON.stringify(data);
        }
      }
    }
    Object.assign(fetchOpt, {
      method: method.toUpperCase(),
      headers: Object.assign({}, headers, moreHeaders, !dataType || dataType === mimeLib.form ? {
        // leave Content-Type' field empty, Fetch APi will automatically create:
        // Content-Type: multipart/form-data; boundary=----WebKitFormBoundaryyEmKNDsBKjB7QEqu
      } : {
        'Content-Type': dataType
      })
    }, data ? {
      body: dataForBody
    } : {});
  }
  /* eslint-enable max-statements */

  _createClass(Hifetch, [{
    key: 'send',
    value: function send() {
      var _this = this;

      var _config2 = this._config,
          url = _config2.url,
          timeout = _config2.timeout,
          validateStatus = _config2.validateStatus,
          disableStatusValidator = _config2.disableStatusValidator,
          mergeHeaders = _config2.mergeHeaders,
          filterHeaders = _config2.filterHeaders,
          disableResponseStyle = _config2.disableResponseStyle,
          responseStyle = _config2.responseStyle,
          enableMeta = _config2.enableMeta,
          enableResponseObject = _config2.enableResponseObject,
          parser = _config2.parser,
          handler = _config2.handler,
          success = _config2.success,
          error = _config2.error;

      var current = uuid();
      this._current = current;
      var _filterHeaders = void 0;
      if (filterHeaders) {
        _filterHeaders = {};
        for (var header in filterHeaders) {
          _filterHeaders[header.toLowerCase()] = filterHeaders[header];
        }
      }
      return new Promise(function (resolve, reject) {
        if (timeout) {
          setTimeout(function () {
            if (current === _this._current) {
              reject(new Error('TIMEOUT'));
            }
          }, timeout);
        }
        return fetch(_this._queryString ? url + '?' + _this._queryString : url, _this._fetchOpt).then(function (res) {
          if (current === _this._current) {
            resolve(res);
          }
        }).catch(function (res) {
          if (current === _this._current) {
            reject(res);
          }
        });
      }).then(function (response) {
        try {
          if (disableStatusValidator || validateStatus(response.status)) {
            return response;
          }
        } catch (e) {
          return error(Object.assign(new Error('[CUSTOM JS ERROR] ' + clearErrorMessage(e)), {
            status: 4,
            error: e
          }));
        }
        var err = new Error(response.statusText);
        err.response = response;
        throw err;
      }).then(function (response) {
        var headersForMerge = {};
        Object.keys(mergeHeaders).forEach(function (key) {
          var header = mergeHeaders[key];
          if (header) {
            headersForMerge[key] = response.headers.get(header);
          }
        });
        var withHeaders = function withHeaders(data) {
          var status = response.status,
              statusText = response.statusText,
              resUrl = response.url,
              headers = response.headers;

          var allHeaders = {};
          var headerEntries = [];
          if (headers._headers) {
            headerEntries = Object.keys(headers._headers).map(function (key) {
              return [key, headers._headers[key].join('; ')];
            });
          } else if (headers.entries) {
            headerEntries = headers.entries();
          }
          var _iteratorNormalCompletion = true;
          var _didIteratorError = false;
          var _iteratorError = undefined;

          try {
            for (var _iterator = headerEntries[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              var i = _step.value;

              if (i && i[0] && (!_filterHeaders || _filterHeaders[i[0]])) {
                allHeaders[i[0]] = i[1];
              }
            }
          } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion && _iterator.return) {
                _iterator.return();
              }
            } finally {
              if (_didIteratorError) {
                throw _iteratorError;
              }
            }
          }

          var meta = {
            status: 0,
            httpStatus: status,
            httpStatusText: statusText,
            url: resUrl,
            headers: allHeaders
          };
          if (enableResponseObject) {
            meta.response = response;
          }
          return {
            data: data,
            headersForMerge: headersForMerge,
            meta: meta
          };
        };
        var parsed = void 0;
        try {
          parsed = parser(response);
        } catch (err) {
          return error(Object.assign(new Error('[CUSTOM JS ERROR] ' + clearErrorMessage(err)), {
            status: 4,
            error: err
          }));
        }
        if (parsed.then) {
          /* eslint-disable promise/no-nesting */
          return parsed.then(withHeaders);
          /* eslint-enable promise/no-nesting */
        }
        return withHeaders(parsed);
      }).then(function (_ref) {
        var data = _ref.data,
            headersForMerge = _ref.headersForMerge,
            meta = _ref.meta;

        try {
          var result = handler(!disableResponseStyle && responseStyle === 'google' && !data.error && data.data || data, headersForMerge, meta);
          if (!disableResponseStyle && (typeof result === 'undefined' ? 'undefined' : _typeof(result)) === 'object') {
            if (responseStyle === 'unix' && result.status < 0) {
              return error(Object.assign(new Error('[REMOTE ERROR] status: ' + data.status + ', message: ' + data.message), Object.assign({}, meta, {
                status: data.status,
                originMessage: data.message,
                data: result
              })));
            } else if (responseStyle === 'google' && result.error) {
              var _result$error = result.error,
                  code = _result$error.code,
                  originMessage = _result$error.message,
                  _result$error$errors = _result$error.errors,
                  errors = _result$error$errors === undefined ? [{}] : _result$error$errors;
              var reason = errors[0].reason;

              return error(Object.assign(new Error('[REMOTE ERROR] reason: ' + reason + ', code: ' + code + ', message: ' + originMessage), Object.assign({}, meta, {
                status: 3,
                code: code,
                originMessage: originMessage,
                reason: reason,
                errors: errors,
                data: result
              })));
            }
          }
          return success(enableResponseObject || enableMeta ? Object.assign({
            data: result
          }, meta) : result);
        } catch (err) {
          return error(Object.assign(new Error('[CUSTOM JS ERROR] ' + clearErrorMessage(err)), Object.assign({}, meta, {
            status: 4,
            error: err
          })));
        }
      }).catch(function (err) {
        if ((typeof err === 'undefined' ? 'undefined' : _typeof(err)) === 'object' && err.message === 'TIMEOUT') {
          return error(Object.assign(new Error('[TIMEOUT ERROR] limit: ' + timeout / 1000 + 's'), {
            status: 5,
            timeout: timeout
          }));
        }
        if (err.status) {
          return error(Object.assign(new Error(err.message), err));
        }

        var _ref2 = err.response || {},
            httpStatus = _ref2.status,
            httpStatusText = _ref2.statusText;

        if (httpStatus) {
          return error(Object.assign(new Error('[FETCH ERROR] ' + httpStatus + ' ' + httpStatusText), {
            status: 2,
            httpStatus: httpStatus,
            httpStatusText: httpStatusText
          }));
        }
        return error(Object.assign(new Error('[INTERNAL JS ERROR] ' + clearErrorMessage(err)), {
          status: 1,
          error: err
        }));
      });
    }
  }, {
    key: 'cancel',
    value: function cancel() {
      this._current = null;
    }
  }, {
    key: 'error',
    value: function error(customError) {
      var error = this._config.error;

      this._current = null;
      return error(Object.assign(new Error('[MANUAL ERROR] ' + clearErrorMessage(customError)), {
        status: 6,
        customError: customError
      }));
    }
  }]);

  return Hifetch;
}();

Hifetch.defaultConfig = {
  url: '',
  method: 'get',
  query: null,
  data: '',
  dataType: 'application/x-www-form-urlencoded',
  FormData: typeof window !== 'undefined' ? window.FormData : null,
  jwtToken: '',
  headers: {},
  timeout: 0,
  responseType: 'application/json',
  mergeHeaders: {},
  filterHeaders: null,
  enableCookies: false,
  disableCORS: false,
  disableResponseStyle: false,
  responseStyle: 'google',
  enableMeta: false,
  enableResponseObject: false,
  disableStatusValidator: false,
  validateStatus: function validateStatus(status) {
    return status >= 200 && status < 300;
  },
  parser: function parser(response) {
    return response.json();
  },
  handler: function handler(data, headersForMerge) {
    return typeof data !== 'string' && !Array.isArray(data) ? Object.assign(headersForMerge, data) : data;
  },

  success: function success(res) {
    return res;
  },
  error: function error(res) {
    return Promise.reject(res);
  }
};


function uuid() {
  return new Date().getTime() * 1000 + Math.floor(Math.random() * 1000);
}

function clearErrorMessage(err) {
  return err.toString(); // .replace(/.+:\s*/, '');
}

function hifetch(opt) {
  return new Hifetch(opt);
}

hifetch.Class = Hifetch;

exports.default = hifetch;

/* eslint-enable filenames/match-exported */

module.exports = exports['default'];
//# sourceMappingURL=index.js.map