'use strict';

var _chai = require('chai');

var _nock = require('nock');

var _nock2 = _interopRequireDefault(_nock);

var _dist = require('../dist');

var _dist2 = _interopRequireDefault(_dist);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('error: 3', function () {
  it('promise style', function (done) {
    (0, _nock2.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error3').reply(200, {
      status: -1,
      message: 'wrong request'
    });
    var fetchConfig = {
      url: _utils.ROOT + '/error3',
      mergeHeaders: {
        poweredBy: 'X-Powered-By'
      },
      responseStyle: 'unix'
    };
    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(-1);
      (0, _chai.expect)(res.data.poweredBy).to.equal('nock');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };
    (0, _dist2.default)(fetchConfig).send().catch(errorHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('callback style', function (done) {
    (0, _nock2.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error3').reply(200, {
      status: -1,
      message: 'wrong request'
    });
    var fetchConfig = {
      url: _utils.ROOT + '/error3',
      mergeHeaders: {
        poweredBy: 'X-Powered-By'
      },
      responseStyle: 'unix'
    };
    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(-1);
      (0, _chai.expect)(res.data.poweredBy).to.equal('nock');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };
    (0, _dist2.default)(Object.assign({}, fetchConfig, {
      error: errorHandler
    })).send().then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('google style response', function (done) {
    (0, _nock2.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error3').reply(400, {
      error: {
        code: 400,
        message: 'wrong request',
        errors: [{
          reason: 'ResourceNotFoundException',
          message: 'wrong request'
        }]
      },
      data: {}
    });
    var fetchConfig = {
      url: _utils.ROOT + '/error3',
      disableStatusValidator: true,
      mergeHeaders: {
        poweredBy: 'X-Powered-By'
      }
    };
    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.code).to.equal(400);
      (0, _chai.expect)(res.originMessage).to.equal(res.errors[0].message);
      (0, _chai.expect)(res.errors[0].reason).to.equal('ResourceNotFoundException');
      (0, _chai.expect)(res.data.poweredBy).to.equal('nock');
      (0, _chai.expect)(res.httpStatus).to.equal(400);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };
    (0, _dist2.default)(fetchConfig).send().catch(errorHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
});
//# sourceMappingURL=error3.spec.js.map